package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(H``````````0```````
M`+$X``````!``#@`"`!``!8`%0````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)RT````````G+0`
M```````0``````$````&````````J\@```````"[R````````+O(````````
M!+`````````5&````````!```````@````8```````"KZ````````+OH````
M````N^@````````!H`````````&@``````````AD=.50````!````````)>0
M````````EY````````"7D`````````"\`````````+P`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````"KR````````+O(````````N\@````````$
M.`````````0X``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````2P````(````'201`"0@`A9KH`(2*012.2`````````!+````3P```%,`
M``!4````60```%H```!;`````````%T``````````````%X```!?````8```
M````````?)I_:@[OT^HM1][.']_%;[:;Q2X.\8VX?-1DU`[D_R$<6''98&RA
M^BP_Y<)OBP&R`<9'XGR2X[O2/,-59LRO9]-P!XCLU45#[=MB,YN<J7\*`J?A
M2?O@HP```````````````````````````````````````````P``!P``````
M`!AH```````````````,$@````````````````````````````&S$@``````
M```````````````````````4$0````````````````````````````'9$0``
M``````````````````````````%5$@`````````````````````````````;
M$@````````````````````````````&2$@``````````````````````````
M```C$@`````````````````````````````J$@``````````````````````
M``````'F$@````````````````````````````&>$@``````````````````
M```````````S(`````````````````````````````,N(0``````````````
M``````````````!+$@````````````````````````````!1$@``````````
M``````````````````+T$@````````````````````````````+E$@``````
M``````````````````````)K$@````````````````````````````!8$@``
M``````````````````````````(,$@````````````````````````````!?
M$@````````````````````````````*@$@``````````````````````````
M``!F$@````````````````````````````!N$@``````````````````````
M``````*)$@````````````````````````````!V$@``````````````````
M``````````!\$@````````````````````````````"%(```````````````
M``````````````+>$@````````````````````````````"A$@``````````
M``````````````````"F$@````````````````````````````'W$0``````
M``````````````````````*G$@````````````````````````````(Y$@``
M``````````````````````````,$$@````````````````````````````(K
M$@````````````````````````````-2$@``````````````````````````
M``*R$0````````````````````````````,M$0``````````````````````
M``````)=$@````````````````````````````,:$@``````````````````
M``````````,O$0````````````````````````````"M$@``````````````
M``````````````,2$@````````````````````````````%C$@``````````
M``````````````````"V(@````````````````````````````#%(```````
M``````````````````````#;$@````````````````````````````+6$@``
M``````````````````````````))$@````````````````````````````#@
M$@````````````````````````````#F(```````````````````````````
M``*4$@````````````````````````````$`$@``````````````````````
M``````&#$@````````````````````````````$%$@``````````````````
M``````````)Y$@````````````````````````````%R$@``````````````
M``````````````$+$@````````````````````````````$<$@``````````
M``````````````````('$@````````````````````````````!W$@``````
M``````````````````````(8$@````````````````````````````)2$@``
M``````````````````````````,+$@````````````````````````````$B
M$@````````````````````````````+\$@``````````````````````````
M``$V$@````````````````````````````("$@``````````````````````
M``````'!$@````````````````````````````$]$@``````````````````
M``````````,L(0````````````````````````````%.$@``````````````
M``````````````,G$@``"0```````"`P`````````E````'3$@``"@``````
M`%@0``````````(```.4$@``"0```````$FP````````"=P```0B$@``"0``
M`````%=0`````````&P```-Q$@``"0```````$.```````````8```.C$@``
M!P```````!AH``````````(```.W$@``"0```````%.0`````````\````00
M$@``"0```````$.(`````````>H```/D$```$P```````,!X````````````
M``."$@``"0```````$D``````````*P```.A$@``"0```````$'(````````
M`#P```.I$@``"0```````$A8`````````'````/7$@``"0```````$5X````
M`````"(```0=$```$P```````-#@``````````````,W$@``"0```````"*P
M`````````#0```/P$@``"0```````$6@`````````2P```/-$0``$@``````
M`,!P``````````@```0)$```$@```````,!X``````````````/I$@``"0``
M`````"*```````````````-`$@``"0```````$C(`````````#8```-;$@``
M"0```````$)H`````````18```/\$@``"0```````$;0`````````8@`;&EB
M<&5R;"YS;P!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT
M9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`;65M<V5T
M`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE435]D
M97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`')E861L:6YK`%]?
M8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`&-L;W-E
M`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R<FYO
M7VQO8V%T:6]N`&UK9&ER`'!T:')E861?9V5T<W!E8VEF:6,`;65M8W!Y`%]?
M<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?
M:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E
M=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?
M<W9?,G!V7V9L86=S`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L
M86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F
M;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`
M<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)C+FUU<VPM<S,Y,'@N<V\N
M,0!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P<FEN
M=&8`<W1R8VAR`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?
M7V5N=FER;VX`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A
M;@!84U]);G1E<FYA;'-?4$%27T)/3U0`;7E?<&%R7W!L`'!A<E]B87-E;F%M
M90!?7V)S<U]S=&%R=`!P87)?9&ER;F%M90!P87)?:6YI=%]E;G8`7V5D871A
M`'!A<E]F:6YD<')O9P!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB+W!E<FPU
M+V-O<F5?<&5R;"]#3U)%``````````````"_@``````````,````````(#``
M``````"_F``````````,````````6!````````"_L``````````,````````
M&&@```````#````````````,````````P`````````#`"``````````,````
M````6F````````#`$``````````,````````6#@```````#`(``````````,
M````````620```````#`*``````````,````````62@```````#`,```````
M```,````````6F8```````#`.``````````,````````6(H```````#`0```
M```````,````````6FX```````#`4``````````,````````6G(```````#`
M6``````````,````````6G@```````#`<``````````,````````6QH`````
M``"_B`````0````*``````````````````"_D`````4````*````````````
M``````"_H`````T````*``````````````````"_J````!T````*````````
M``````````"_N````"$````*``````````````````"_P````"<````*````
M``````````````"_R````"L````*``````````````````"_T````"\````*
M``````````````````"_V````#`````*``````````````````"_X````#4`
M```*``````````````````"_Z````#H````*``````````````````"_\```
M`#L````*``````````````````"_^````$`````*``````````````````"]
MH`````(````+``````````````````"]J`````,````+````````````````
M``"]L`````8````+``````````````````"]N`````<````+````````````
M``````"]P`````@````+``````````````````"]R`````D````+````````
M``````````"]T`````H````+``````````````````"]V`````L````+````
M``````````````"]X`````P````+``````````````````"]Z`````T````+
M``````````````````"]\`````\````+``````````````````"]^````!``
M```+``````````````````"^`````!$````+``````````````````"^"```
M`!(````+``````````````````"^$````!,````+``````````````````"^
M&````!0````+``````````````````"^(````!4````+````````````````
M``"^*````!8````+``````````````````"^,````!<````+````````````
M``````"^.````!@````+``````````````````"^0````!D````+````````
M``````````"^2````!H````+``````````````````"^4````!L````+````
M``````````````"^6````!P````+``````````````````"^8````!X````+
M``````````````````"^:````!\````+``````````````````"^<````"``
M```+``````````````````"^>````"(````+``````````````````"^@```
M`",````+``````````````````"^B````"0````+``````````````````"^
MD````"4````+``````````````````"^F````"8````+````````````````
M``"^H````"D````+``````````````````"^J````"H````+````````````
M``````"^L````"P````+``````````````````"^N````"T````+````````
M``````````"^P````"X````+``````````````````"^R````"\````+````
M``````````````"^T````#`````+``````````````````"^V````#$````+
M``````````````````"^X````#(````+``````````````````"^Z````#,`
M```+``````````````````"^\````#0````+``````````````````"^^```
M`#8````+``````````````````"_`````#<````+``````````````````"_
M"````#@````+``````````````````"_$````#D````+````````````````
M``"_&````#P````+``````````````````"_(````#T````+````````````
M``````"_*````#X````+``````````````````"_,````#\````+````````
M``````````"_.````$$````+``````````````````"_0````$(````+````
M``````````````"_2````$,````+``````````````````"_4````$0````+
M``````````````````"_6````$4````+``````````````````"_8````$8`
M```+``````````````````"_:````$<````+``````````````````"_<```
M`$@````+``````````````````"_>````$H````+``````````#K[_!P`"2Y
M!``/I_O_8.,`\```),#E```%TL#E```?G^OO\1``!`?^XQ#P.``DP!```%)Y
MT@?P,!`(XQ`0$``$!_$'``<`!P#`$```4GCC$!````0'\0T0XQ`0#``4P/3_
M___E`````,`0``!2;.,0$```!`?Q#1#C$!`,`!3`]/___]4````8P!```%)@
MXQ`0```$!_$-$.,0$`P`%,#T____Q0```##`$```4E3C$!````0'\0T0XQ`0
M#``4P/3___^U````2,`0``!22.,0$```!`?Q#1#C$!`,`!3`]/___Z4```!@
MP!```%(\XQ`0```$!_$-$.,0$`P`%,#T____E0```'C`$```4C#C$!````0'
M\0T0XQ`0#``4P/3___^%````D,`0``!2).,0$```!`?Q#1#C$!`,`!3`]/__
M_W4```"HP!```%(8XQ`0```$!_$-$.,0$`P`%,#T____90```,#`$```4@SC
M$!````0'\0T0XQ`0#``4P/3___]5````V,`0``!2`.,0$```!`?Q#1#C$!`,
M`!3`]/___T4```#PP!```%'TXQ`0```$!_$-$.,0$`P`%,#T____-0```0C`
M$```4>CC$!````0'\0T0XQ`0#``4P/3___\E```!(,`0``!1W.,0$```!`?Q
M#1#C$!`,`!3`]/___Q4```$XP!```%'0XQ`0```$!_$-$.,0$`P`%,#T____
M!0```5#`$```4<3C$!````0'\0T0XQ`0#``4P/3___[U```!:,`0``!1N.,0
M$```!`?Q#1#C$!`,`!3`]/___N4```&`P!```%&LXQ`0```$!_$-$.,0$`P`
M%,#T___^U0```9C`$```4:#C$!````0'\0T0XQ`0#``4P/3___[%```!L,`0
M``!1E.,0$```!`?Q#1#C$!`,`!3`]/___K4```'(P!```%&(XQ`0```$!_$-
M$.,0$`P`%,#T___^I0```>#`$```47SC$!````0'\0T0XQ`0#``4P/3___Z5
M```!^,`0``!1<.,0$```!`?Q#1#C$!`,`!3`]/___H4```(0P!```%%DXQ`0
M```$!_$-$.,0$`P`%,#T___^=0```BC`$```45CC$!````0'\0T0XQ`0#``4
MP/3___YE```"0,`0``!13.,0$```!`?Q#1#C$!`,`!3`]/___E4```)8P!``
M`%%`XQ`0```$!_$-$.,0$`P`%,#T___^10```G#`$```433C$!````0'\0T0
MXQ`0#``4P/3___XU```"B,`0``!1*.,0$```!`?Q#1#C$!`,`!3`]/___B4`
M``*@P!```%$<XQ`0```$!_$-$.,0$`P`%,#T___^%0```KC`$```41#C$!``
M``0'\0T0XQ`0#``4P/3___X%```"T,`0``!1!.,0$```!`?Q#1#C$!`,`!3`
M]/___?4```+HP!```%#XXQ`0```$!_$-$.,0$`P`%,#T___]Y0```P#`$```
M4.SC$!````0'\0T0XQ`0#``4P/3___W5```#&,`0``!0X.,0$```!`?Q#1#C
M$!`,`!3`]/___<4```,PP!```%#4XQ`0```$!_$-$.,0$`P`%,#T___]M0``
M`TC`$```4,CC$!````0'\0T0XQ`0#``4P/3___VE```#8,`0``!0O.,0$```
M!`?Q#1#C$!`,`!3`]/___94```-XP!```%"PXQ`0```$!_$-$.,0$`P`%,#T
M___]A0```Y#`$```4*3C$!````0'\0T0XQ`0#``4P/3___UU```#J,`0``!0
MF.,0$```!`?Q#1#C$!`,`!3`]/___64```/`P!```%",XQ`0```$!_$-$.,0
M$`P`%,#T___]50```]C`$```4(#C$!````0'\0T0XQ`0#``4P/3___U%```#
M\,`0``!0=.,0$```!`?Q#1#C$!`,`!3`]/___34```0(P!```%!HXQ`0```$
M!_$-$.,0$`P`%,#T___])0``!"#`$```4%SC$!````0'\0T0XQ`0#``4P/3_
M__T5```$.,`0``!04.,0$```!`?Q#1#C$!`,`!3`]/___04```10P!```%!$
MXQ`0```$!_$-$.,0$`P`%,#T___\]0``!&C`$```4#CC$!````0'\0T0XQ`0
M#``4P/3___SE```$@,`0``!0+.,0$```!`?Q#1#C$!`,`!3`]/___-4```28
MP!```%`@XQ`0```$!_$-$.,0$`P`%,#T___\Q0``!+#`$```4!3C$!````0'
M\0T0XQ`0#``4P/3___RU```$R,`0``!0".,0$```!`?Q#1#C$!`,`!3`]/__
M_*4```3@P!```$_\XQ`0```$!_$-$.,0$`P`%,#T___\E0``!/C`$```3_#C
M$!````0'\0T0XQ`0#``4P/3___R%```%$,`0``!/Y.,0$```!`?Q#1#C$!`,
M`!3`]/___'4```4HP!```$_8XQ`0```$!_$-$.,0$`P`%,#T___\90``!4#`
M$```3\SC$!````0'\0T0XQ`0#``4P/3___Q5```%6,`0``!/P.,0$```!`?Q
M#1#C$!`,`!3`]/___$4```5PP!```$^TXQ`0```$!_$-$.,0$`P`%,#T___\
M-0``!8CK;_`P`"3`T```.Z'C\/](_W'C,/"H`"3C0/"@`"10(/"T04#PH$$P
M\*A!(/"TP.7___YIQ$@``$_*Q"@``$_#N00`-,#E___\[L08``!/BY4`$`"G
M=``?P.7___W$Q"L``%@EN0(`(J=T``>G*0`!P.7___YXP.7___[5Q!@``$^&
MXR`0```6P.7___],D@`I(<2X``!/>^,@L```%L#E____098")/KC(+```!;`
MY?___SE8$/"TE@$D^NPA``4`V$$0T`"Y%``BXR`0```AI\0`"\0X``!/7L`@
M```<F<#E___\4.LB``,`#<#E___^>N.P\*@`!.,0L```!.,0(```),`0```<
M[^,0(`@`)%A`\+3$&```3Y;C$"`0`"021,`0```<XN,0(!@`)*<X``'`$```
M5[/$*P``5ZSE3!````2G60``&!2Y\M`3IUL``:<6`&KL%``$`-BG2@`#N10`
M$>L1``,`#>,1+_C_<;D$`%+E2!````"G:0``N10`1,`P```0*\0H``!7D,#E
M___\R1BR$B*G=``)Q"@``%>&P.7___W_&++$*```5W_`Y?___6C`(```&WC`
MY0``#4JY`@`BIW0`(<`0``!7:^,0$````J=T``O`(```&S[`Y0``#3C$*P``
M5UW`$```5UKC$!````*GA``(Q"@``%=2P.4``!J/Q"@``%=0P.7___ZYP.7_
M__M6N10`*^MO\.@`!`?^ZP4``P`-[#4`!`#8N00`8+D4`#/C!K````3K,P`#
M``WC`R_X_R2G]/^!N00`+\`P````$N,P,```&*?[_V"G"0``XP#P```DP/0`
M```)!P<'!P``F4`'!P<'04`@",!0___ZVNMO\#``)./P_UC_<<!@```:I>5(
M\*```.,P(`0`%,`@___^K,#E___\^0<'!P?`$```3LC`(```3L6Y(``2IX0`
M"L08``!.5KD"`!&GA``#!_$'_@<'P#```$ZTP!```$ZQN0D`$^L1``,`"NLQ
M`#\`#+D(`#'K,P`!``JY`@`SIX0`#<08``!.4;D"`!&GA``&P"```$Z6!_$'
M_@<'P!```$Z0E0`0``=^ZZ_P4``DP!```$XSX_#_8/]QXQ`0```"IX0`",0H
M``!.0,#E___\Y<"P``!,)L"@``!,)[D)`*OKJ@`#``JGJ___Q!@``$YMN2$`
M&J=$`!S`Y?___YK`$```3?/C$!````*GA``(P"```#I#P.7___L`P!```$Y1
MD@$0`.NO\/``!`?^IQL``<0;``!.2NL1``,`#>,1L```!`WAI_3_TP<'!P?K
M[_!P`"3C\/]@_W'K[_$0``0'_@<'!P?`$```3=SC$!````*GA``4P#```$XL
MP"```#H-Z^_P<``DX_#_8/]QP.7___R4Z^_Q$``$P/3___]>!P<'!P<'Z^_P
M<``DX_#_8/]QZ^_Q$``$!_X'!P<'LD\`$.L1`"``#;)/`!'K;_`P`"2G60`(
MX_#\T/]QI[D``-('\R@0*$$0\*BY!``QXTL@.``$ZP0`(``,XP`P```DP$H`
M````XT`P"``DI[L`"*<[`!"G5__MITD`0.,P$&@`!.,P$$``@N,P$!``@N,P
M$```@NQ3(+\A5>Q3(#X!5N-0$(``)*<;``BG1__IXQ#PJ``$PAI:@GF9XQ`@
M(``(XU`@```$XY`@$``$XZ`@"``$X[`@&``$[$4@OR55[$4@.@56N0@`0;GG
ML!FY@``:N8(`&^LZ``(`#+D(`$'L.@`A'E;C$/"P``3L8R"_`%7"&EJ">9FY
MYV")N0@`&[F``(6Y@@")N0@`&,!*`````.N$`!L`#.R$(#H%5KD(`('K%0`"
M``SL%0`A'E:YYQ`#XS#PN``$N8``!,(Z6H)YF;F"``:Y"``YN0@`,,"*````
M`.QQ(+\`5>L(`!L`#.P((#H%5KD(``/K-``"``SL-``A'E:YYS!!XQ#PP``$
MN8``2,(:6H)YF;F"`$>Y"``6N0@`%,`*`````.S3(+\`5>M``!L`#.Q`(#H%
M5KD(`$'K&``"``SL&``A'E:YYQ"#XS#PR``$N8``@,(Z6H)YF;F"`(VY"``W
MN0@`.,!*`````.QA(+\`5>N$`!L`#.R$(#H%5KD(`(/K,``"``SL,``A'E:Y
MYS`!XQ#PT``$N8``!,(:6H)YF;F"``:Y"``=N0@`$,"*`````.QS(+\`5>L(
M`!L`#.P((#H%5KD(``'K%``"``SL%``A'E:YYQ!#XS#PV``$N8``2,(Z6H)Y
MF;F"`$>Y"``VN0@`-,`*`````.S1(+\`5>M``!L`#.Q`(#H%5KD(`$/K.``"
M``SL.``A'E:YYS"!XQ#PX``$N8``@,(:6H)YF;F"`(VY"``7N0@`&,!*````
M`.QC(+\`5>N$`!L`#.R$(#H%5KD(`('K$``"``SL$``A'E:YYQ`#XS#PZ``$
MN8``!,(Z6H)YF;F"``:Y"``]N0@`,,"*`````.QQ(+\`5>L(`!L`#.P((#H%
M5KD(``/K-``"``SL-``A'E:YYS!!XQ#P\``$N8``2,(:6H)YF;F"`$>Y"``6
MN0@`%,`*`````.S3(+\`5>M``!L`#.Q`(#H%5KD(`$'K&``"``SL&``A'E:Y
MYQ"#XS#P^``$N8``@,(Z6H)YF;F"`(VY"``WN0@`.,!*`````.QA(+\`5>N$
M`!L`#.R$(#H%5KD(`(/K,``"``SL,``A'E:YYS`!XQ#Q```$N8``!,(:6H)Y
MF;F"``:Y"``=N0@`$,"*`````.QS(+\`5>L(`!L`#.P((#H%5KD(``'K%``"
M``SL%``A'E:YYQ!#XS#Q"``$N8``2,(Z6H)YF;F"`$>Y"``VN0@`-,`*````
M`.S1(+\`5>M``!L`#.Q`(#H%5KD(`$/K.``"``SL.``A'E:YYS"!XQ#Q$``$
MN8``@,(:6H)YF;F"`(VY"``7N0@`&,!*`````.QC(+\`5>N$`!L`#.R$(#H%
M5KD(`('K$``"``SL$``A'E:YYQ`#XS#Q&``$N8``!,(Z6H)YF;F"``:Y"``]
MN0@`,,"*`````.QQ(+\`5>L(`!L`#.P((#H%5KD(``/K-``"``SL-``A'E:Y
MYS!!XQ#Q(``$N8``2,(:6H)YF;F"`$>Y"``6N0@`%,`*`````.S3(+\`5>M`
M`!L`#.Q`(#H%5KD(`$'K&``"``SL&``A'E:YYQ"#XS#Q*``$N8``@,(Z6H)Y
MF;F"`(VY"``WN0@`.,!*`````.QA(+\`5>N$`!L`#.R$(#H%5KD(`(/K,``"
M``SL,``A'E:YYS`!XQ#Q,``$N8``!,(:6H)YF;F"``:Y"``=N0@`$,"*````
M`.QS(+\`5>L(`!L`#.P((#H%5KD(``'K%``"``SL%``A'E:YYQ!#XS#Q.``$
MN8``2,(Z6H)YF;F"`$>Y"`!CN0@`9,`*`````.S1(+\`5>M``!L`#.Q`(#H%
M5KD(`$;K:``"``SL:``A'E:YYV"!XQ#Q0``$N8``@,(:6H)YF;F"`(VY"`!Q
MN0@`>.PT(+\`5>N#`!L`#.R#(#H%5KD(`(?K<``"``SL<``A'E:YYW`&N8(`
M0.,`\4@`!,(*;MGKH;D(`-"Y&@#4[!@@OP!5ZP$`&P`,[`$@.@56N0@`#>O3
M``(`#.S3`"$>5N,P\5``!,(Z;MGKH;D:`#:YY]!GN8(`ANQ`(+\`5;D:`#CK
M80`"``RY!`"#[&$`(1Y6XQ#Q6``$PAINV>NAN1H`%[GG8'WK-``;``RY@@`'
M[#0@.@56ZW0``@`,N0@`..QT`"$>5NR#(+\`5>-`\6``!,)*;MGKH;D:`$VY
MYW#6N8(`/;D:`!"Y&@!#N00``;D$`#3K&``;``SKV``"``SL&"`Z!5;LV``A
M'E:Y"``0[`$@OP!5ZT``&P`,[$`@.@56N0@`0^PT(+\`5>.`\6@`!,**;MGK
MH;D:`(:YY]!GN8(`%KD:`('K8``"``RY!``8[&``(1Y6XP#Q<``$P@INV>NA
MN1H`![GG8'VY@@!'ZX,`&P`,N1H`!.R#(#H%5KD$`$"Y"`"!ZW,``@`,[!@@
MOP!5[',`(1Y6XS#Q>``$PCINV>NAN1H`/;GG<-:Y@@"-ZP$`&P`,N1H`..P!
M(#H%5KD$`(.Y"``$Z]$``@`,[$`@OP!5[-$`(1Y6XQ#Q@``$PAINV>NAN1H`
M%KGGT&>Y@@`&ZS0`&P`,N1H`$.PT(#H%5KD$``&Y"``XZV0``@`,[(,@OP!5
M[&0`(1Y6XT#QB``$PDINV>NAN1H`1[GG8'VY@@`WZQ@`&P`,N1H`0^P8(#H%
M5KD$`#2Y"``0ZW@``@`,[`$@OP!5['@`(1Y6XX#QD``$PHINV>NAN1H`C;GG
M<-:Y@@`=ZT``&P`,N1H`@>Q`(#H%5KD$`!BY"`!#Z]```@`,[#0@OP!5[-``
M(1Y6XP#QF``$P@INV>NAN1H`!KGGT&?K@P`;``RY@@!&[(,@.@56ZV,``@`,
MN0@`@>QC`"$>5NP8(+\`5>,P\:``!,(Z;MGKH;D:`#>YYV!]N8(`A[D:``2Y
M&@`XN00`0+D$`(/K`0`;``SL`2`Z!5:Y"``$[$`@OP!5ZS0`&P`,[#0@.@56
MN0@`..N!``(`#.R!`"$>5N,0\:@`!,(:;MGKH;D:`!VYYX#6N8(`#>QS(+\`
M5;D:`!#KU``"``RY!``![-0`(1Y6XT#QL``$PDINV>NAN1H`1KGGT&BY@@`V
MZQ<`&P`,N1H`0^P7(#H%5KD$`#2Y"``0ZV<``@`,[`$@OP!5[&<`(1Y6XW#Q
MN``$PGINV>NAN1H`>+GG8(VY@@`8ZT``&P`,N1H`<>Q`(#H%5KD$`!>Y"`!#
MZX```@`,[#0@OP!5[(``(1Y6XP#QP``$P@INV>NAN1H`#;GG@-:Y@@!-ZW,`
M&P`,N1H`!.QS(#H%5KD$`$"Y"`!QZ],``@`,[!<@OP!5[-,`(1Y6XS#QR``$
MPCINV>NAN1H`-KGGT&BY@@!VZP$`&P`,N1H`-^P!(#H%5KD$`'.Y"``$ZV$`
M`@`,[$`@OP!5[&$`(1Y6XQ#QT``$PAINV>NAN1H`&+GG8(WK-``;``RY@@`(
M[#0@.@56ZX0``@`,N0@`-^R$`"$>5NQS(+\`5>-`\=@`!,)*;MGKH;D:`$VY
MYX#6N8(`/;D:`!"Y&@!#N00``;D$`#3K%P`;``SL%R`Z!5:Y"``0[`$@OP!5
MZT``&P`,[$`@.@56N0@`0^LW``(`#.PW`"$>5N-P\>``!,)Z;MGKH;D:`':Y
MYS!HN8(`%KD:`''`2@````"Y!``7[-,@OP!5ZW0`&P`,['0@.@56N0@`<>L0
M``(`#.P0`"$>5NQA(+\`5;GD8`VY@0`QN8``-+F!`##C`/'H``3""H\;O-RY
M&@`(N0@`,,!Z`````.L'`!L`#.P'(#H%5KD(``/K-``"``SL-``A'E;L@R"_
M`%6YYC!!N>2`%KF``$>Y@0!!XQ#Q\``$PAJ/&[S<N0@`';D(`!3`"@````#K
M0``;``SL0"`Z!5:Y"`!!ZQ<``@`,[!<`(1Y6[-$@OP!5N>80<[GDT#BY@`!P
MN8$`<^,P\?@`!,(ZCQN\W+D(`#:Y"``WP$H`````ZW0`&P`,['0@.@56N0@`
M<^LP``(`#.PP`"$>5NQC(+\`5;GF,`&YY&`=N8``!+F!``'C$/(```3"&H\;
MO-RY"``8N0@`$,!Z`````.L'`!L`#.P'(#H%5KD(``'K%``"``SL%``A'E;L
M@2"_`%6YYA!#N>2`-KF``$>Y@0!#XS#R"``$PCJ/&[S<N0@`/;D(`#3`"@``
M``#K0``;``SL0"`Z!5:Y"`!#ZS<``@`,[#<`(1Y6[-,@OP!5N>8P<;GDT!BY
M@`!PN8$`<>,0\A``!,(:CQN\W+D(`!:Y"``7P$H`````ZW0`&P`,['0@.@56
MN0@`<>L0``(`#.P0`"$>5NQA(+\`5;GF$`.YY&`]N8``!+F!``/C,/(8``3"
M.H\;O-RY"``XN0@`,,!Z`````.L'`!L`#.P'(#H%5KD(``/K-``"``SL-``A
M'E;L@R"_`%6YYC!!N>2`%KF``$>Y@0!!XQ#R(``$PAJ/&[S<N0@`';D(`!3`
M"@````#K0``;``SL0"`Z!5:Y"`!!ZQ<``@`,[!<`(1Y6[-$@OP!5N>80<[GD
MT#BY@`!PN8$`<^,P\B@`!,(ZCQN\W+D(`#:Y"``WP$H`````ZW0`&P`,['0@
M.@56N0@`<^LP``(`#,!Z`````.PP`"$>5NQC(+\`5;GF,`&YY&`=N8``!+F!
M``'C$/(P``3"&H\;O-RY"``8N0@`$.L'`!L`#.P'(#H%5KD(``'K%``"``SL
M%``A'E;L02"_`%6YYA"#N>1`-KF``(>Y@0"#XS#R.``$PCJ/&[S<N0@`/;D(
M`#C`"@````#K@``;``SL@"`Z!5:Y"`"#ZS<``@`,[#<`(1Y6[-,@OP!5N>8P
M<;GDT!2Y@`!PN8$`<>,0\D``!,(:CQN\W+D(`!:Y"``7P(H`````ZW@`&P`,
M['@@.@56N0@`<>L0``(`#.P0`"$>5NP!(+\`5;GD`&VY@0`QN8``.+F!`#;C
M8/)(``3":H\;O-RY"`!DN0@`8\!Z`````.M(``(`#.LW`!L`#.Q(`"$>5NPW
M(#H%5KGF0(&Y"``V[&0@OP!5N>1@$+F``(>Y@0"!XQ#R4``$PAJ/&[S<N0@`
M';D(`!C`.@````#K@P`;``SL@R`Z!5:Y"`"!ZQ<``@`,[!<`(1Y6[-$@OP!5
MN>80=+GDT$:Y@`!SN8$`=.-`\E@`!,)*CQN\W+D(`$"Y"`!'P(H`````ZP,`
M`@`,ZW@`&P`,[`,`(1Y6['@@.@56[#`@OP!5N0@`=+GF`$&YY#`=N8``2+F!
M`$'C$/)@``3"&H\;O-RY"``6N0@`%,!Z`````.M'`!L`#.Q'(#H%5KD(`$'K
M&``"``SL&``A'E;L@2"_`%6YYA!@N>2``[F``&>Y@0!@XP#R:``$P@J/&[S<
MN0@`#;D(``;`2@````#K9``;``SL9"`Z!5:Y"`!@ZP<``@`,[`<`(1Y6[-`@
MOP!5N>30>+F!`!"Y@``4N8$`%^-P\G``!,)ZCQN\W+D(`'.Y"`!QP&H`````
MZS0``@`,ZQ8`&P`,[#0`(1Y6[!8@.@56N>8P0+D(`!>Y@`!&[',@OP!5N>1P
M#;F!`$#`&@````#C`/)X``3""H\;O-RY"`"`N0@`A.M!`!L`#.Q!(#H%5KD(
M`$CC0/"@`"3LA""_`%7K!@`"``SL!@`A'E;L8""_`%6YY&!'N8$`,+F``#&Y
M@0`TXT#R@``$PDJ/&[S<N0@`U.M!``(`#.Q!`"$>5KF"``2Y"`#3N00`%.-`
M\*``!+F"`$#C`/*(``3""LIBP=;K.``;``RY"`!P[#@@.@56N1H`=+D(`#WK
M"``"``SLTR"_`%7L"``A'E:YYP"!N8(`@[D$`$?C,/*0``3K?0`;``S".LIB
MP=;L?2`Z!5:Y"``VN1H`..N-``(`#.R-`"$>5N/0\I@`!,+:RF+!UKD:`-&Y
M!``=N0@`=+GG@-#L1R"_`%6Y@@!]Z]0``@`,[-0`(1Y6ZV0`&P`,[&0@.@56
MN00`3>/0\J``!,+:RF+!UKD:`-"Y!``-N>=`V+D(`&.Y&@`7[#8@OP!5N8(`
M;>O3``(`#.S3`"$>5KD$`''K$P`;``SL$R`Z!5:Y!``]X]#RJ``$PMK*8L'6
MN1H`V+D$`(VYYS#4N0@`%[D:``;L<2"_`%6Y@@`=Z]<``@`,[-<`(1Y6N00`
M8.L'`!L`#.P'(#H%5KD$`'WCT/*P``3"VLIBP=:Y&@#4N00`3;GG<-.Y"``&
M[&`@OP!5N8(`#>O6``(`#.S6`"$>5KD:`('K%@`;``SL%B`Z!5:Y!`!MX]#R
MN``$PMK*8L'6N1H`T[D$`#VY"``8N>=@U^R!(+\`5;D:`$"Y@@`=Z]@``@`,
M[-@`(1Y6N00`!.M(`!L`#.Q((#H%5KD$`(WCT/+```3"VLIBP=:Y&@#7N00`
M?;D(`$"YYX#6[`0@OP!5N8(`3>O0``(`#.S0`"$>5KD:`#'K$``;``SL$"`Z
M!5:Y!``-X]#RR``$PMK*8L'6N1H`UKD$`&VYYP#8N0@`$^PQ(+\`5;F"`!WK
MTP`"``SLTP`A'E:Y&@!TZT,`&P`,[$,@.@56N00`/>/0\M``!,+:RF+!UKD:
M`-BY!`"-N><PT+D(`$?L=""_`%6Y@@!-Z]<``@`,[-<`(1Y6N1H`8>L7`!L`
M#.P7(#H%5KD$`'WCT/+8``3"VLIBP=:Y&@#0N00`#;D(`!:YYW#3[&$@OP!5
MN8(`'>O6``(`#.S6`"$>5KD:`(3K1@`;``SL1B`Z!5:Y!`!MX]#RX``$PMK*
M8L'6N1H`T[D$`#VYYV#7N0@`2.R$(+\`5;F"`$WKV``"``SLV``A'E:Y&@`!
MZQ@`&P`,[!@@.@56N00`C>/0\N@`!,+:RF+!UKD:`->Y!`!]N>>`UKD(`!"Y
M&@`T[`$@OP!5N8(`'>O0``(`#.S0`"$>5KD$`$/K,``;``SL,"`Z!5:Y!``-
MX]#R\``$PMK*8L'6N1H`UKD$`&VYYP#8N1H`<;D(`#3L0R"_`%6Y@@`]Z]0`
M`@`,N1H`8^S4`"$>5NL4`!L`#.P4(#H%5KD$`$VY"``7X]#R^``$['$@OP!5
MPMK*8L'6ZS<`&P`,N1H`V.PW(#H%5KD(`#;L8R"_`%6Y!`"-N>=`T+F"`!WK
MUP`"``SLUP`A'E:Y!`!]X]#S```$PMK*8L'6N1H`T+D$``VYYW#4N8(`/>O6
M``(`#.S6`"$>5KD:`('K%@`;``SL%B`Z!5:Y!`!MX]#S"``$PMK*8L'6N1H`
MU+D$`$VYYV#7N0@`&.R!(+\`5;F"`!WKV``"``SLV``A'E:Y&@`#ZS@`&P`,
M[#@@.@56N00`C>/0\Q``!,+:RF+!UKD:`->Y!`!]N>>`UKD(`##L`R"_`%6Y
M@@`]Z]```@`,[-``(1Y6N1H`0>L0`!L`#.P0(#H%5KD$``WCT/,8``3"VLIB
MP=:Y&@#6N00`;;D:`'.YYP#8N0@`%.Q!(+\`5;F"`!WCT/,@``2Y&@!APMK*
M8L'6N1H`V.LT`!L`#+D$`(WL-"`Z!5:Y"``W[',@OP!5ZQ<`&P`,[!<@.@56
MN0@`%NMD``(`#,`:`````.QD`"$>5KD$`$:YYT#0N8(`/;D(`*&Y&@"#P*H`
M````XZ`@"``DZS$`&P`,N1H`M.PQ(#H%5L"Z`````..P(!@`)+D(`#CC$"`@
M``2Y&@!3N1H`$,!:`````.-0(```),`:`````.,0("``).MG``(`#.QG("$>
M5KD(`);`F@````#CD"`0`"2R3P`0ZQ$`(``-LD\`$=4'\R@0**>$``7`Y?__
M\ACK;_-@``0'_@<'ZV_P,``DX_#_8/]QN0(`@J>$`$S$&```0?+C8!````*G
MA`!$N00`2.,00```E!(1IW0`,!M(N00`<[D$`*:Y%`"TXY"@```"IX0`'KD$
M`$NY!``XXR"@```$P.7__^^#$B*G=``?01N0`)4]$`"G=``9N0D`ID&;D`'K
MJ@`#``I0H'``N00`*>MO\-``!`?^IQX`/:>$_]!!0$`!I_3_QD&@H`BG]/_/
MIYD``*?T_^SK[_!P`"2R3P`0ZQ$`(``-LD\`$>/P_U#_<4$P\*32!_"H$"C`
MY?___Y:R3P`0ZQ$`(``-LD\`$=4'\*@0**>$``7`Y?__\9?K[_$@``0'_NNO
M\%``)+)/`!#C\/]0_W'K$0`@``VY!`"RLD\`$4&@\*32!_"H$"BY!``ZN00`
M*\#E____:+D"`"*G=``1LD\`$.L1`"``#;)/`!'5!_"H$"BGA``?P.7___%E
MXQ#PI``4Q"@``$%+ZQ$``P`-XQ`@```(XR`0"``$XR`0```DN0(`(J>$_])!
M$!`(I_3_].NO\0``!`?^ZV_P,``DLD\`$./P_U#_<>L1`"``#;)/`!&Y!`"B
MN00`L]('\*@0*)4],`"G=``$0;`P`:<(``"Y!``;IYD``+)>`)&G%/_^N0D`
MFT$P\*2Y!``JP.7___\*N0(`(J>$`#*G"```IQD``+D$`#*R7@`3IQ3__KD)
M`!*Y(0`9IT0`BZ<9``#C,;```)!",2``IQL``;D"`#.G=/_WIR@``+)/`!"Y
M%``BZQ$`(``-LD\`$=4'\*@0**>$`,W`Y?__\.;$&```0,_C<!````2G&0``
M&(&G&P`!ZR$``P`-XR)_^/\"IW3_]^PH``(`V,`0``!),;D4`"+C$!```!+K
M(@`#``VGA``7N00`,KD$`"?`Y?__[4S$&```0*7C(!```"2Y`@`BIW0`(Z<H
M__^G]/^YP!```$D/Y4P0```!P.7__^XEN0(`8J>$__&Y%`!(N00`-^M$``,`
M#<#E___N)\08``!`@.-@$```)+D4`!C$*```0'BG&P`!XR`@```$ZQ$``P`-
M01$@`.5($````%"`\*2Y!``:XR`0``"4$B*GA``&IRX`/:=T`$VY"0`:N10`
M$<2(``!`5N-P\*0`%$$I$`+K=P`#``WC<(````C`Y?__[=SC('```"2Y`@`B
MIX3_I>,0\*0`%.,@@```!.L1``,`#>,A(```!.,0H```D$(0(`!!H*`!03`@
M`<`;````_Z>$``:G'@`]IW0`%Y(](`"G&0``XR&P``"00B$P`*<;``&Y`@`B
MIW3_]Z?T_R]!$!`!I_3_J;D$`".G]/_7ZV_PX``$!_X'!P<'!P?K?_`X`"2R
M3P`0X_#^R/]QZQ$`(``-LD\`$;D"`*+2!_$P$"BGA``BE0"@`*>$`![`Y?__
M[%RY`@""IX0`%T%P\*"Y!``HP.7__^T1N0(`(J=T`!NY!``HP.7__^VXN00`
M*L#E___O([)/`!#K$0`@``VR3P`1U0?Q,!`HIX0`;,#E___OU$&P(!/`$```
M"_.G"```N00`*[)=`!*G%/_^IX3_T<`0```+Y[D$`"NR70`2IQ3__J>$_\:Y
M!``:IRD``+D$`#NR7@`AIQ3__J<9``"Y"0`JLEX`$Z<4__ZY"0`;&B&G*@`"
MN10`(L#E___M'KD$`%NY!`"2N00`2L`P```+O,#E___O4KD$`#>Y!``IP.7_
M_^\+IR[__[D$`"FGA``56!#PN,`;``#P`*<>0`"G=``,P.7___]EN00`*<#E
M___NY*?T_W[`Y?__[-^G]/_VZW_Q<``$!_X'!P<'LD\`$.L1`"``#;)/`!'K
MO_!8`"3C\/[(_W&Y!`"R03#PH-('\3`0*,#E___M$!(BIW0`+A@26"#PN,`K
M``#P`*<N0`"GA``'PBT``*``IW0`#J<Y``*Y!``KP.7__^OG$!*G&O__B!``
M'[D4`"&R3P`0ZQ$`(``-LD\`$=4'\3`0**>$``G`Y?__[R&G&```I_3_[>N_
M\9``!`?^!P<'!^OO\'``),08```^]>/P_V#_<>,@$```%L#E___NN,!0```J
MS<1(```^_L`P```+*>OO\1``!,#T___NB0<'!P?K;_`P`"3C\/]8_W'$N```
M/M+C(+```!;`8```#'C`Y?__[I7`Y?___\[C(+```!;`Y?__[HRY!`!6Y4CP
MH```P$````BDP#````L)P.7__^N>ZV_PV``$!_X'!P<'!P?K;_`P`"2R3P`0
MX_#_4/UQZQ$`(``-XR#PJ`)QLD\`$=('(``0*$&P\*;`8```"O+`Y?__Z[S`
M0```"NZY!`!2ISD0`;D$`"O`Y?__ZV"G+O__IW0`&*>Y``"R3P`0XS#PJ`)Q
MZQ$`(``-N00`*[)/`!'5!S``$"BGA`!+P.7__^Z&$B+L(!``('&G1/_FXZ#P
MIP%QITD0`+D$`#JY!``KP.7__^STN00`@A(BIT3_U:<J``&Y%``BP.7__^OH
MN0(`LJ>$_\JY%`"8N2$`NJ>D``:YZ)`;N6%`H;DA`+JGQ``&N>B0&KEA0+&Y
M!`!)N00`.NR`$`$@<KD$`"O`Y?__[A9!&;``D@`0`*?T_ZCK;_#@`@0'_@<'
MP/3___]T!P?K;_`P`"2R3P`0X_#^P/YQN00`LNL1`"``#>,@\3@!<;)/`!&Y
M!`"#T@<@`!`HP"````IHP.7___QBISD`+[D$`)*Y!``KP.7__^Q!N0(`(J>$
M`!ZY!``[P"````I8P.7___S!LD\`$.,P\3@!<>L1`"``#;D$`"NR3P`1U0<P
M`!`HIX0`L,#E___M\:<(``"Y!``;N00`**>I``#`,```"CU!@/$XLEX`H:<4
M__Y!</"H&ZO`Y?__[7JGJ@`!N0(`(J>$_\F5`"``P!````GSN>*`(;D"`)FG
MA``8IP@``+D$`!*Y!``YLET`$Z<4__ZG=``,P#````H1IRD``,#E___M5:?T
M_]VG"```IQD``+D$`#*R7@`3IQ3__AL2N10`,>,S+___<94O,`"GA``B&AJG
M'@__IR3_C^.P\*``)+D$`%+`8```">K`0```"EJG.1``N00`*,#E___J2*<J
M``'"+P``$`"GQ``.I_0``:<:__^Y%``Q03,@`)(`,`"G]/_/N00`-[D$`"C`
MY?__[.X2(J=T_[!8$/#`P!L``/``PAT``(``IW3_IJ<Y``&Y!``HP.7__^H*
M$B*G=/^<N00`.,`@```)HL#E___\"[D$`"C`Y?__ZRJY!`"RI_3_0^MO\7`!
M!`?^!P<'!P<'N00`$N,P$```E!(SIW0``P?^01`0`:<^`"^YXH`AI_3_\P<'
M!P<'![D"`#*GA``&E0`P`*=T``C`(```"43`]/__ZOVY!``CIP@``*<9``"R
M7@`2IQ3__KGI,"'C0!___W&Y(0`TIR0`!J<___^G=``$IRD``:<G`!2Y(``T
MIW0`)I4O,`"GA/_9P"````E/I_3_U^-`3___<:?T_^Z5+T``IX3_^;GI,!3C
M($___W&Y(0`RIRD``;GB,!+C($___W&5+T``IW0`.+GI,!3C($___W&Y(0`R
MIR0`!J<___^G=``$IQD``>-`3___<:<7`"JY"0!#[!0``@#9PAX``!``IR0`
M)J=+``'`(```/1OK[_!P`"3C\/]@_W'L0!``(''`Y?__ZSO`(```/0SK[_$0
M``0'_KD$`$*G%__!I_3_GI4O0`"GA/_1I_3_U*<I```'_@<'!P>R3P`0ZQ$`
M(``-LD\`$>OO\'``)./P_S#_<<`@```(W-('\,@0*,`0```H+=(A\*80`,#E
M___ZY\`@```(TL#E___ZX<`@```(T,#E___ZV\`@```(S\#E___ZU<`@```(
MS<#E___ZS\`@```(S\#E___ZR<`@```(H<#E___ZP\`@```(R<#E___ZO<`@
M```(R,#E___ZM\`@```(Q\#E___ZL<`@```(CL#E___ZJ\`@```(P,#E___Z
M?;D"`#*GA``(P"````BLP.7___KGP"````BYP.7___IMN0(`,J>$``C`(```
M"+C`Y?__^M?`(```"+C`Y?__^EVY`@`RIX0`(,`@```(6<#E___ZQ\`P```(
MO\`@```(<,#E___ZOK)/`!#K$0`@``VR3P`1U0?PR!`HIX0`)<#E___K\\`@
M```(F,#E___Z-;D"`#*GA``'P"````A?I_3_V*=)``K`,```")!!(/"WP.7_
M_^EZ$B*G=/_.03#PP:?T_^SK[_%```0'_L0=```\"*<>__^G=``OZ^_P<``D
MP"````@[X_#_8/]QP.7___H$N0(`(J>$`!OC$"```)"Y`@`1IX0`%,`7````
M,+D#`!'L$3^_`57$'P``.^+$+```.]_K[_$0``0'_J<8``"G]/_TQ"P``#O4
M!_[K[_!P`"3C\/]@_W'`Y?__ZY[`Y?__Z=NY`@`BIX0`">,@(```!.OO\1``
M!`?^IRD``*?T__H'!^MO\#``)+D$`++C\/]@_W'`(```""C`Y?__^;6Y!``[
MN0(`8J>$``:5`&``IW0`"\`@```(&.MO\-``!,#T___Z%L#E___I5[D"`"*G
M=``LIP@``+D$`!NY!``VLEX`(:<4__ZG&0``N0D`*[)>`!.G%/_^N0D`%D$B
M$`+`Y?__Z+K`,```"`*Y!`"BP%````>)N00`2\#E___J[;D$`#JG]/_(ZV_P
MT``$!_X'!P<'ZV_P,``DN00`[^/P_@#W<:?K_^A@@.``8*#@"&#`X!"R3P`0
MZQ$`(``-LD\`$;D$`++C(/'@"''2!R``$"C`$```.PW`(```!TG2#_"P$`#2
M!_#`$!#`$```.PW2+_#@$`#`$```.Q_2#_#($`#2!_#8$!#`Y?__^2ZY`@"B
MIX0`))4`H`"GA``@P.7___]CN00`*L#E___HMKD$`(*R3P`0XS#QX`AQZQ$`
M(``-N00`*+)/`!'5!S``$"BGA`2#P.7__^K`P.7___\IN0(`DJ=T`"=!H/#(
MXQ"@```"IW0`!\"0```';Z?T`!OC(*````3`Y?__^.^Y`@`2IW0`!J>K``BG
M]/_JE0`0`*>$__K`Y?__Z'BY`@"2IX3_\Z<(``"Y!``9IRD``+)>`"&G%/_^
MN0D`*>LB``$`#:<K``'`Y?__Z`"Y!`"BN00`@N-`D```E!)$IW0`*$&0\.#C
M@)````*GA``=XR"0```$P.7___BQN0(`@J>$`">5`(``IX0`(\#E___Z^A(B
MIX0`';D$`"C`Y?__Z#:Y!`""09#PL*?T`"BY!``HN10`1,`P```'#4&0D`%!
M@(`"P.7__^H"I_3_QJ>;``BG]/_*XR"0```$P.7___K2$B*GA``)N00`)\#E
M___H#KD$`(*GFP`(N0(`B*=T``OC<)````*GA``&E0!P`*=T_^.G"```N00`
M&*>9``"R7@"1IQ3__KD$`"JG&0``N0D`F+)>`!*G%/_^N0D`&AJ1IYH$!+D4
M`)FY!``IP.7__^=]XZ#PH``DN00`<L!0```&3;D$`$C`,```!KK`8```!K3`
MY?__Z:JG.0'`N00`)\#E___I0Z<N__^G=``HP.7__^DL6!`@`*<>`!&GA``?
MX["P```$P.7__^D@Q!@``#F9XV`@```4N00`5[D$`$O`,```!I+C(!````3`
MY?__Z)VGB0``I_3^YT$0\1"Y!``GL\$`@;D$`#'`Y?__YVX8HA(BIX0`%<08
M```Y<[D$`%?C0+````3`,```!HSC(!````3`Y?__Z'FG]/_<6!#Q*,`;``#P
M`*<>0`"G=/_F6(#Q+,#E___IF1F"IW3_WE@0\2C`&P```?^G'@'`IW3_U;D$
M`"G`Y?__YOBY!`""P"````:*P.7___>XN0(`(J=T`,WCD+````2G"```IQD`
M`+D$`"FR7@`2IQ3__KD)`!FG'@`#I\0`1+D4`"'C,I_\_W'`(```!FNR70`C
MIQ3__J=T`#:G'@`$IX0`#:<:__RY%``1XQ&?__]QE2\0`*=T`"?C(+`(``*G
MA``BIP@``*<9``"Y!``RLEX`$Z<4__ZY"0`2PAX````#I\0`$>,A+_S_<<`0
M```&/;)=`!*G%/_^IW0`!>.0L`@`!,#E___]2!(BIW0">[D$`"FG.0``P.7_
M_^;ZN00`LAB2$B*GA`)NITD``J<Y_^[`Y?__Y?U!8/'@ITD`!KD$`#:Y!``K
MP.7__^@2E0#QX*=T`&*50_'AIW0`7I5!\>*G=`!:E4/QXZ=T`%:52/'DIW0`
M4I5%\>6G=`!.ITD``J<Y_\:Y!``KP.7__^71ITD`*;D$`#:Y!``KP.7__^?H
MP!````95P%````4:XQ#PH``DN00`1\`P```%VKD$`"C`Y?__Z'6Y!``GP.7_
M_^@@N00`.,`@```$]L#E___W9+D$`"C`Y?___2NG]/W/XY"P```$P.7__^9[
MN00`,KD$`"G`Y?__^F"Y`@"2IW3_*:?T_R2G20``ISD``+D$`"O`Y?__Y87`
M$6=%(P'C$/$0`"3E2/$X``#`'^_-JXGC$/$8`"3E2/%```#`'YBZW/[C$/$@
M`"3E3/&(``#`$1`R5';C$/$H`"3`'\/2X?#C$/$P`"2Y%``9L\$`H4$0\8BS
MP0#!I4^``+D$`#:SS0`J09#Q2,#E___G:[D$`-(8HA(BIR0`XK/-`"K`Y?__
MYT#CL/$X``3CH/%```3L&SJ_/57L00`!`-BY%``101'Q2)*`$`"G3@`XN10`
M)*?$`8:G&`!`ISD``+GY0$%!(I``N10`1,#E___E:[/-`"C`Y?__ZEJG20`X
MISD``+D$`"E!D/&CP.7__^5;0J#Q@T*P\8?K&@`8``Q"$/&`ZQH`$``,0A#Q
M@>L:``@`#$(0\8*SS0`HZQL`&``,0A#QA*>I`!3K&P`0``Q"$/&%ZQL`"``,
M0A#QAD&P\;>Y!`!KP.7__^HBXQ#Q$``$0A#QINLA`!@`#$(@\:/K(0`0``Q"
M(/&DZR$`"``,0B#QI>,0\1@`!$(0\:KK(0`8``Q"(/&GZR$`$``,0B#QJ.LA
M``@`#$(@\:GC$/$@``1"$/&NZR$`&``,0B#QJ^LA`!``#$(@\:SK(0`(``Q"
M(/&MXQ#Q*``$ZR$`&``,0B#QKT(0\;+K(0`0``Q"(/&PZR$`"``,0B#QL>,0
M\3``!.LA`!@`#$(@\;-"$/&VZR$`$``,0B#QM.LA``@`#$(@\;7C0)```)"Y
M!``KP#````0VIYL``:>[``+`Y?__YRNGI__QD@#QWZ?T_I_C,/$X``2Y%``M
MZQ(``P`-N0@`$\`:`````+DA`#&GQ``%ZP'Q0`!ZXQ#Q.``DZR(`'0`,XR#Q
M0``(XR#Q0``DXQ#QB``2IX0`FJ>H`$`;H1G:N00`*;GRP*VY&``AN10`NKDA
M`":GI``(N>BP$KDA`&&G1``,N2$`)J?$``JYZ+`6N2$`(:>D``2G]``!PKX`
M`(``IR3_^[D$`$NY!``VP.7__^;B&!I:$/&(4!#QB*<>`$"G=/ZUN?F@K;D(
M`+:SS0`HP.7__^E$N00`.^NZ``8`WJ>Z``$2JJ<8``&Y\E"QI_0`)KDA`#FG
MQ``(L\T`'+DA`#&G1/_*N2$`.4'0,$"GI``&N2$`G:=$_\"G20!`N00`*<#E
M___FI[/-`"BGJO_`P.7__^D4N00`/:>V_]RY%`!*N2$`.:?$``BYZ$`9N2$`
M,:=$_Z*Y(0`YIZ0`"+GH0!.Y(0"1IT3_F,).````2*<D_Y.Y!``IP.7__^9\
M4*#QB*?T_E2Y!`"VI_3_IJ<8`#BG.0``N?E`04$BD`"Y%`!$I_3^BL`P```#
M3,`@```#"\#E___U2\"P```$',#E___CF<`0```$%KD$`&+C$/"@`"3`4```
M`M:Y!`!'P#````.AN00`*,#E___F-*<Y`<"Y!``HP.7__^7-IR[__Z=T_;;`
MY?__Y;98$"``IQX`$:=T_:VGJ@`!P.7__^-KN10`&KD$`&+CL/"H`"3C$/"@
M`"3`4````J:Y!`!'P#````-XN00`*,#E___F!*?T_]#M@/'H"&7MH/'P"&7M
MP/'X"&7K;_(P"`0'_@<'!P?K;_`P`"3C\/]@_W'$N```-@[C(+```!;`Y?__
MY=2Y!`"BXR"P```6P.7__^7,T@`@N:"XP"````*!P.7___1;N0(`(J>$``J5
M,2``IW0`!I4`(`&GA``%P.7___ETQ!@``#7EXR`0```6P.7__^6KIUD`"Z=)
M``'`,````SW`Y?__Y!&Y`@`BIW0`3<2H```USN,@H```%L#E___EE*=9``.G
M20`!P#````,IP.7__^/ZN0(`LJ=T`+G$J```-;?C(*```!;`Y?__Y7VG60`#
MITD``<`P```#%L#E___CX[D"`+*GA`#LP"````(,P.7___0!N0(`DJ>$`,7C
M(*```!;`Y?__Y5_C$+`0``2Y!`!)XS`0```$P.7__^/DI_0`S^,0(!``!*>X
M``'C@!`H``3$F```-7OLJ___`-A8()``QKT``#W[IZ0`%+D6`"+`Y?__Y3BG
M60``N10`2KD$`#C`Y?__XK^Y`@!RIW0`$<0=```]Y*<:__\9H:=T_XBGN``!
MQ*@``#52I_0`1L0H```]T;D4`!OK$0`#``WC82````3C$'````18(!`,P"L`
M(`0`IRX$`*=T`!'C(!`0``2G"```LET`)J<4__ZG=/_1I[H``:?T_['C()``
M`!;`Y?__Y/"G60`"ITD``.,P<```!,#E___E)J?T_^2Y%@`BI[H``<#E___D
MW;D$`#C`Y?__X9A8(*``QKT``#V/IT3_[Z?T_S3C(*```!;`Y?__Y,GC$+`0
M``3`0````F#C,!````3`Y?__XTWC$+`0``3C$!````210!`-IX3_+^,@H```
M%L#E___DK>,0L!``!.,P$```!,#E___B5*?T_Q[`Y?__]BNY`@"2XR"@```6
MIX0`8,#E___DE>,0L!``!+D$`$GC,!````3`Y?__XQJY!``IP.7__^1%Q+@`
M`#2VXR"P```6P.7__^1\N00`HN,@L```%L#E___D=*=)``'`,````A#`Y?__
MX5S`0````A6Y!``RN00`*L#E___B\N,@L```%L#E___D7)(`(+G`(````/+`
MY?__\NS$*P``/1&Y`@`BIW0`(\0H```]`L#E___Y=\0K```]!+D"`"*G=``6
MP"````'LP.7__^%JP.7__^0WQ#@``#SLXQ"P$``$XT`P```$I_3^U*<Y`<#$
M*```/.?`Y?__X]2G+@`1IX0`&^P2``$`V,(?`````:?$`!/$&```/,VY!`!2
MQ$@``#S0XS`0```$P"````'*P.7__^$WZV_PT``$!_[KK_!0`"3C\/]@_W&Y
M!`"RP.7___<@P.7___<)N00`HL#E___X=!(BIX0`'KD"`+NGA``:E0"P`*>$
M`!;`,````/FY!``JP.7__^(MN2``HJ=T``JY!``KZZ_P\``$P/3___0-ZZ_P
M\``$!_X'!P<'Z[_P6``DX_#_8/]QP+```#'^XQ"P```$IQ___Z=T``;KO_#X
M``0'_N.PO_C_<0WAI_3_\0<'!P?K[_!P`"3C\/]@_W'K[_$0``0'_@<'!P?K
M[_!P`"2Y!``/I_O_8.,`\```),#E___EFNOO\1``!`?^````````+@`N+@``
M)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ
M4$%2.CI"3T]4``!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35```%!!4E]04D]'
M3D%-10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%4DPU3U!4``!015),24\`
M`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%
M0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'``!005)?1TQ/0D%,7U1-
M4$1)4@!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@``4$%27T-,14%./0``,0!,1%],24)205)97U!!5$@`4UE35$5-```E
M,#)X``!P87(M```E<R5S)7,E<P``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42```<&%R;```+G!A
M<@``)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M
M)74E<P``+W1M<```5$5-4$1)4@!435``55-%4@``55-%4DY!344``$%21U8`
M`!@`<&5R;```,`!005(Z.E!A8VME<CHZ5D524TE/3@``,2XP-#<`56YA8FQE
M('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H``"UE```M+0``979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M
M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D
M978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U
M=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E
M;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$[
M"G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I
M>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L
M("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N
M86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I
M;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\
M?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD
M;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T
M("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(
M+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE
M*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*
M?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D
M+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K
M97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U
M9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG
M="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D
M9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@
M)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*
M96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E
M8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*
M;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D
M<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N
M=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M
M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK
M*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM
M;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S
M(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H
M9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E
M;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^
M("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI
M("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L
M(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@
M*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F
M:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2![
M"G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN
M8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I
M=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N
M9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,[
M"FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?
M<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@
M*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O
M7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@
M/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H
M+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*
M;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT
M.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*
M?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@
M;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&
M24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H
M+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD
M9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%
M4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D
M<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X]
M(")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H
M+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U
M+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E
M;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF
M("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O
M9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*
M<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R
M96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]
M"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L
M;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@
M)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2([
M"F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D
M14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,
M14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]
M?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("```````````!__________<&5R;'AS
M:2YC``````````$;`SL```"\````%O__B*````3@__^,Z````-C__Z1````!
M%/__I/````%0__^E0````7#__Z78```!H/__J#@```'<__^IF````A3__ZHX
M```"0/__JG@```)@__^JV````IS__ZOP```"V/__J_@```+L__^MZ````RC_
M_ZX0```#//__KT````-@__^PR````X3__[$X```#L/__L7````/4__^R(```
M!"#__[P````$:/__O\````2D`````````!0``````7I2``%X#@$;#`^@`0``
M`````#@````<__^,"```%U8`6(8.APV(#(D+B@J+"8P(C0>.!H\%1@[0!P,7
M-L_.S<S+RLG(Q\8.H`$``````#@```!8__^C)````+``1H8.APV(#(D+B@J+
M"8P(C0>.!H\%1@[``@*""L_.S<S+RLG(Q\8.H`%""P```!P```"4__^CF```
M`%``5(X&CP5&#M`"=,_.#J`!````+````+3__Z/(````F`!*B@J+"8P(C0>.
M!H\%1@[0`@*&S\[-S,O*#J`!````````.````.3__Z0P```"6@!*A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5&#M`"`P)(S\[-S,O*R<C'Q@Z@`0``````-````2#_
M_Z94```!7`!*APV(#(D+B@J+"8P(C0>.!H\%1@[8`P,!2L_.S<S+RLG(QPZ@
M`0`````H```!6/__IWP```"<`%2+"8P(C0>.!H\%1@[8`P*`S\[-S,L.H`$`
M`````!P```&$__^G\````#P`3(X&CP5&#L`"9,_.#J`!````.````:3__Z@0
M````6@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L@"`DS/SLW,R\K)R,?&#J`!
M````````.````>#__Z@T```!%@!*A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M!"
M`P$$S\[-S,O*R<C'Q@Z@`0``````$````AS__ZD0````!@`````````X```"
M,/__J00```'J`$J&#H<-B`R)"XH*BPF,"(T'C@:/!48.X",#`=C/SLW,R\K)
MR,?&#J`!```````0```";/__JK@````B`````````"````*`__^JS````2P`
M`NZ.!H\%1@[``EC/S@Z@`0```````"````*D__^KV````8@`5(X&CP5&#O`"
M`P%LS\X.H`$``````"@```+(__^M/````'``6HX&CP5&#L`"?@K/S@Z@`4(+
M2`Z@`<[/````````(````O3__ZV`````-@!&C@:/!48.P`)@"L_.#J`!0@L`
M````2````QC__ZV4````K`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#L`";`K/
MSLW,R\K)R,?&#J`!1@L":,_.S<S+RLG(Q\8.H`$``````$0```-D__^M^```
M"=P`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@Z@A0)0F!>9%IH5`PFZS\[-S,O*
MR<C'QMK9V`Z@`0```````#@```.L__^WD````\``1H8.APV(#(D+B@J+"8P(
MC0>.!H\%1@[``@,#LL_.S<S+RLG(Q\8.H`$``````#@```/H__^[%````&P`
M1HH*BPF,"(T'C@:/!48.P`("4@K/SLW,R\H.H`%&"T;/SLW,R\H.H`$`````
M`#P```0D__^#N````E``1H8.APV(#(D+B@J+"8P(C0>.!H\%3`[8`@,"$@K/
MSLW,R\K)R,?&#J`!0@L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#__________P``````````__________\`````````````
M```````!``````````$``````````0````````+!``````````\````````$
M+@`````````,````````&&@`````````#0```````%@0`````&___O4`````
M```"&``````````%````````"_``````````!@````````+8``````````H`
M```````$3``````````+`````````!@`````````%0``````````````````
M``,```````"]B``````````"````````!:``````````%``````````'````
M`````!<````````2R``````````'````````$$``````````"`````````*(
M``````````D`````````&``````````8````````````````;___^P`````(
M```!`````&____D`````````#@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````N^@`````````````````````````````&+X`````
M```8W@```````!C^````````&1X````````9/@```````!E>````````&7X`
M```````9G@```````!F^````````&=X````````9_@```````!H>````````
M&CX````````:7@```````!I^````````&IX````````:O@```````!K>````
M````&OX````````;'@```````!L^````````&UX````````;?@```````!N>
M````````&[X````````;W@```````!O^````````'!X````````</@``````
M`!Q>````````''X````````<G@```````!R^````````'-X````````<_@``
M`````!T>````````'3X````````=7@```````!U^````````'9X````````=
MO@```````!W>````````'?X````````>'@```````!X^````````'EX`````
M```>?@```````!Z>````````'KX````````>W@```````![^````````'QX`
M```````?/@```````!]>````````'WX````````?G@```````!^^````````
M']X````````?_@```````"`>````````(#``````````````````````````
M````6!``````````````````````````````&&@`````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#``````````%I@````````6#@`````````````
M`````%DD````````62@```````!:9@```````%B*````````6FX`````````
M`````````%IR````````6G@``````````/____\`````````````6QI'0T,Z
M("A!;'!I;F4@."XR+C`I(#@N,BXP```N<VAS=')T86(`+FEN=&5R<``N9VYU
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M
M90`N8W1O<G,`+F1T;W)S`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M````````````````````````````````````````"P````$``````````@``
M``````(``````````@``````````&`````````````````````$`````````
M`````!-O___V``````````(````````"&`````````(8`````````+P````#
M```````````````(```````````````=````"P`````````"`````````M@`
M```````"V`````````D8````!`````(`````````"``````````8````)0``
M``,``````````@````````OP````````"_`````````$3```````````````
M``````$``````````````"T````$``````````(````````00````````!!`
M`````````H@````#```````````````(`````````!@````W````!```````
M``!"````````$L@````````2R`````````6@`````P```!$`````````"```
M```````8````00````$`````````!@```````!AH````````&&@`````````
M*`````````````````````(``````````````#P````!``````````8`````
M```8D````````!B0````````!Z`````````````````````$`````````"``
M``!'`````0`````````&````````(#`````````@,````````#?@````````
M````````````"```````````````30````$`````````!@```````%@0````
M````6!``````````(@````````````````````(``````````````%,````!
M``````````(```````!8.````````%@X````````/U@`````````````````
M```(``````````````!;`````0`````````"````````EY````````"7D```
M``````"\````````````````````!```````````````:0````$`````````
M`@```````)A0````````F%`````````$9`````````````````````@`````
M`````````',````!``````````,```````"[R````````*O(`````````!``
M```````````````````(``````````````!Z`````0`````````#````````
MN]@```````"KV``````````0````````````````````"```````````````
M@0````8``````````P```````+OH````````J^@````````!H`````0`````
M``````````@`````````$````(H````!``````````,```````"]B```````
M`*V(`````````G@````````````````````(``````````@```"/`````0``
M```````#````````P`````````"P``````````!X````````````````````
M"```````````````E0````@``````````P```````,!X````````L'@`````
M```0:`````````````````````@``````````````)H````!`````````#``
M`````````````````+!X`````````!H````````````````````!````````
M``$````!`````P````````````````````````````"PD@````````"C````
5`````````````````0``````````
